Module network

Module network 

Enums

CloseReason
Reasons for closing a connection
MsgAcceptance
NetworkEvent
Network events that the network will report when subscribing
SendError

Constants

MIN_SUPPORTED_MSG_SIZE
Network implementations have to at least support messages of this size.
MIN_SUPPORTED_REQ_SIZE
Network implementations have to at least support requests of this size.
MIN_SUPPORTED_RESP_SIZE
Network implementations have to at least support responses of this size.

Traits

Network
PubsubId
Topic

Type Aliases

SubscribeEvents