pub enum CloseReason {
Other,
RemoteClosed,
GoingOffline,
Error,
MaliciousPeer,
}Expand description
Reasons for closing a connection
Variants
Other
Reason is unknown or doesn’t fit the other reasons
RemoteClosed
The other peer closed the connection
GoingOffline
We need to close the connection to this peer because we are going offline and don’t want new connections.
Error
There was an error and there is need to close the connection
MaliciousPeer
Peer is malicious. This will cause the peer ID and address to get banned.