pub enum NetworkEvent<P> {
PeerJoined(P, PeerInfo),
PeerLeft(P),
DhtReady,
}Expand description
Network events that the network will report when subscribing
Variants
PeerJoined(P, PeerInfo)
A connection to a new peer has been started
PeerLeft(P)
A peer disconnected
DhtReady
DHT is ready (bootstrapped and in server mode) to publish records