pub struct Services(/* private fields */);Expand description
Bitmask of services
- This just serializes to its numeric value for serde, but a list of strings would be nicer.
Implementations
Sourceimpl Services
impl Services
Sourcepub const FULL_BLOCKS: Self
pub const FULL_BLOCKS: Self
The node provides at least the latest [nimiq_primitives::policy::NUM_BLOCKS_VERIFICATION] as full blocks.
Sourcepub const ACCOUNTS_PROOF: Self
pub const ACCOUNTS_PROOF: Self
The node provides inclusion and exclusion proofs for accounts that are necessary to verify active accounts as well as accounts in all transactions it provided from its mempool.
However, if Services::ACCOUNTS_CHUNKS is not set, the node may occasionally not provide a proof if it
decided to prune the account from local storage.
Sourcepub const ACCOUNTS_CHUNKS: Self
pub const ACCOUNTS_CHUNKS: Self
The node provides the full accounts tree in form of chunks. This implies that the client stores the full accounts tree.
Sourcepub const MEMPOOL: Self
pub const MEMPOOL: Self
The node tries to stay on sync with the network wide mempool and will provide access to it.
Nodes that do not have this flag set may occasionally announce transactions from their mempool and/or reply to mempool requests to announce locally crafted transactions.
Sourcepub const TRANSACTION_INDEX: Self
pub const TRANSACTION_INDEX: Self
The node provides an index of transactions allowing it to find historic transactions by address or by hash. Only history nodes will have this flag set. Nodes that have this flag set may prune any part of their transaction index at their discretion, they do not claim completeness of their results either.
Sourcepub const VALIDATOR: Self
pub const VALIDATOR: Self
This node is configured as a validator, so it is interested for other validator nodes.
Sourcepub const PRE_GENESIS_TRANSACTIONS: Self
pub const PRE_GENESIS_TRANSACTIONS: Self
This node provides pre-genesis information.
Sourceimpl Services
impl Services
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl Services
impl Services
Sourcepub const fn iter(&self) -> Iter<Services>
pub const fn iter(&self) -> Iter<Services>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Services>
pub const fn iter_names(&self) -> IterNames<Services>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.