Module request

Module request 

Structs

MessageMarker
RequestMarker
RequestType

Enums

InboundRequestError
OutboundRequestError
RequestError
Error enumeration for requests

Constants

DEFAULT_MAX_REQUEST_RESPONSE_TIME_WINDOW
The range to restrict the responses to the requests on the network layer.

Traits

Handle
This trait defines the behaviour when receiving a message and how to generate the response.
Message
MessageHandle
This trait defines the behaviour when receiving a message
Request
RequestCommon
RequestKind
RequestSerialize

Functions

message_handler
Handler that takes care of sending messages to a network, similar to a request except that we don’t expect an answer.
peek_type
request_handler