pub enum OutboundRequestError {
ConnectionClosed,
DialFailure,
NoReceiver,
SendError,
SenderFutureDropped,
SerializationError,
Timeout,
UnsupportedProtocols,
NoResponse,
Other(String),
}Variants
ConnectionClosed
The connection closed before a response was received.
It is not known whether the request may have been received (and processed) by the remote peer.
DialFailure
The request could not be sent because a dialing attempt failed.
NoReceiver
No receiver was found for this request and no response could be transmitted
SendError
Error sending this request
SenderFutureDropped
Sender future has already been dropped
SerializationError
Request failed to be serialized
Timeout
Timeout waiting for the response of this request. In this case a receiver was registered for responding these requests but the response never arrived before the timeout was hit.
UnsupportedProtocols
The remote supports none of the requested protocols.
NoResponse
No response after asking a couple of peers.
Other(String)
Error that doesn’t match any of the other error causes