pub fn message_handler<T: Send + Sync + Clone + 'static, Msg: MessageHandle<N, T> + Message, N: Network>(
_network: &Arc<N>,
stream: BoxStream<'static, (Msg, N::PeerId)>,
req_environment: &T,
) -> impl Future<Output = ()>Expand description
Handler that takes care of sending messages to a network, similar to a request except that we don’t expect an answer.