Structs
Enums
- Inbound
Request Error - Outbound
Request Error - Request
Error - Error enumeration for requests
Constants
- DEFAULT_
MAX_ REQUEST_ RESPONSE_ TIME_ WINDOW - The range to restrict the responses to the requests on the network layer.
Traits
- Handle
- This trait defines the behaviour when receiving a message and how to generate the response.
- Message
- Message
Handle - This trait defines the behaviour when receiving a message
- Request
- Request
Common - Request
Kind - Request
Serialize
Functions
- message_
handler - Handler that takes care of sending messages to a network, similar to a request except that we don’t expect an answer.
- peek_
type - request_
handler